/* faq.js -- Functions for FAQ/Doc page

   Copyright 2013, 2014 by John K. Hinsdale.  See LICENSE.html for terms of use.
*/

// Toggle text of show/hide button and visibility of DIV
function toggle_show_hide(ev, section_id) {
    var button_id = ev.currentTarget.id;
    var section_elt = document.getElementById(section_id);
    var section_sty = getComputedStyle(section_elt);
    var cur_vis = section_sty.display;
    set_show_hide(button_id, section_id, cur_vis == "none");
}

// Set text of show/hide button and visibility of DIV
function set_show_hide(button_id, section_id, make_visible) {
    var button_elt = document.getElementById(button_id);
    var section_elt = document.getElementById(section_id);
    if ( make_visible ) {
        section_elt.style.display = "initial";
        button_elt.innerHTML = "Hide";
    }
    else {
        section_elt.style.display = "none";
        button_elt.innerHTML = "Show";
    }
}

// Mark sections hidden on load and add handlers
function on_page_load() {
    var secs = [ "faq", "rules", "actions", "functional" ];
    for (var i=0; i<secs.length; i++)
        set_show_hide("button_" + secs[i], "section_" + secs[i], true);
}

// Load options from storage
document.addEventListener('DOMContentLoaded', on_page_load);

// Click handlers to show/hide sections
document.getElementById('button_faq').addEventListener('click', function(ev) { toggle_show_hide(ev, 'section_faq'); } );
document.getElementById('button_rules').addEventListener('click', function(ev) { toggle_show_hide(ev, 'section_rules'); } );
document.getElementById('button_actions').addEventListener('click', function(ev) { toggle_show_hide(ev, 'section_actions'); } );
document.getElementById('button_functional').addEventListener('click', function(ev) { toggle_show_hide(ev, 'section_functional'); } );

// $Id: faq.js,v 1.7 2014/12/26 17:53:08 hin Exp $
